@@ -25,10 +25,6 @@ class InlineQueryView(BaseView):
     async def execute(cls, q: InlineQuery, state: FSMContext = None, **kwargs):
         raise NotImplementedError
 
-    @classmethod
-    async def _execute(cls, q: InlineQuery, state: FSMContext = None, **kwargs):
-        await cls.execute(q, state, **kwargs)
-
     @classmethod
     def register(cls, dp: Dispatcher):
         callback = cls._execute
