@@ -1,3 +1,5 @@
+import logging
+
 from aiogram import Dispatcher
 from aiogram.types import Poll
 from aiogram.dispatcher import FSMContext
@@ -6,14 +8,11 @@ from .base import BaseView
 
 
 class PollView(BaseView):
+
     @classmethod
     async def execute(cls, p: Poll, state: FSMContext = None, **kwargs):
         raise NotImplementedError
 
-    @classmethod
-    async def _execute(cls, p: Poll, state: FSMContext = None, **kwargs):
-        await cls.execute(p, state, **kwargs)
-
     @classmethod
     def register(cls, dp: Dispatcher):
         callback = cls._execute
