@@ -6,13 +6,14 @@ from .base import BaseView
 
 
 class PollAnswerView(BaseView):
+
     @classmethod
-    async def execute(cls, p: PollAnswer, state: FSMContext = None, **kwargs):
-        pass
+    async def execute(cls, pa: PollAnswer, state: FSMContext = None, **kwargs):
+        raise NotImplementedError
 
     @classmethod
     def register(cls, dp: Dispatcher):
-        callback = cls.execute
+        callback = cls._execute
         kwargs = cls.register_kwargs if cls.register_kwargs else {}
         custom_filters = cls.custom_filters if cls.custom_filters else []
         dp.register_poll_answer_handler(callback, *custom_filters,
