@@ -6,13 +6,14 @@ from .base import BaseView
 
 
 class ShippingQueryView(BaseView):
+
     @classmethod
     async def execute(cls, q: ShippingQuery, state: FSMContext = None, **kwargs):
-        pass
+        raise NotImplementedError
 
     @classmethod
     def register(cls, dp: Dispatcher):
-        callback = cls.execute
+        callback = cls._execute
         kwargs = cls.register_kwargs if cls.register_kwargs else {}
         custom_filters = cls.custom_filters if cls.custom_filters else []
         dp.register_shipping_query_handler(callback, *custom_filters, state=cls.state(),
